==> types_boto3_s3tables-1.35.74.tar.gz: types_boto3_s3tables-1.35.74/types_boto3_s3tables/paginator.py <==
"""
Type annotations for s3tables service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_s3tables.client import S3TablesClient
    from types_boto3_s3tables.paginator import (
        ListNamespacesPaginator,
        ListTableBucketsPaginator,
        ListTablesPaginator,
    )

    session = Session()
    client: S3TablesClient = session.client("s3tables")

    list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
    list_table_buckets_paginator: ListTableBucketsPaginator = client.get_paginator("list_table_buckets")
    list_tables_paginator: ListTablesPaginator = client.get_paginator("list_tables")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListNamespacesRequestListNamespacesPaginateTypeDef,
    ListNamespacesResponseTypeDef,
    ListTableBucketsRequestListTableBucketsPaginateTypeDef,
    ListTableBucketsResponseTypeDef,
    ListTablesRequestListTablesPaginateTypeDef,
    ListTablesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListNamespacesPaginator", "ListTableBucketsPaginator", "ListTablesPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListNamespacesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListNamespaces.html#S3Tables.Paginator.ListNamespaces)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listnamespacespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListNamespacesRequestListNamespacesPaginateTypeDef]
    ) -> _PageIterator[ListNamespacesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListNamespaces.html#S3Tables.Paginator.ListNamespaces.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listnamespacespaginator)
        """


class ListTableBucketsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTableBuckets.html#S3Tables.Paginator.ListTableBuckets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablebucketspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTableBucketsRequestListTableBucketsPaginateTypeDef]
    ) -> _PageIterator[ListTableBucketsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTableBuckets.html#S3Tables.Paginator.ListTableBuckets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablebucketspaginator)
        """


class ListTablesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTables.html#S3Tables.Paginator.ListTables)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTablesRequestListTablesPaginateTypeDef]
    ) -> _PageIterator[ListTablesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTables.html#S3Tables.Paginator.ListTables.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablespaginator)
        """

==> types_boto3_s3tables-1.36.0.tar.gz: types_boto3_s3tables-1.36.0/types_boto3_s3tables/paginator.py <==
"""
Type annotations for s3tables service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_s3tables.client import S3TablesClient
    from types_boto3_s3tables.paginator import (
        ListNamespacesPaginator,
        ListTableBucketsPaginator,
        ListTablesPaginator,
    )

    session = Session()
    client: S3TablesClient = session.client("s3tables")

    list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
    list_table_buckets_paginator: ListTableBucketsPaginator = client.get_paginator("list_table_buckets")
    list_tables_paginator: ListTablesPaginator = client.get_paginator("list_tables")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListNamespacesRequestPaginateTypeDef,
    ListNamespacesResponseTypeDef,
    ListTableBucketsRequestPaginateTypeDef,
    ListTableBucketsResponseTypeDef,
    ListTablesRequestPaginateTypeDef,
    ListTablesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListNamespacesPaginator", "ListTableBucketsPaginator", "ListTablesPaginator")


if TYPE_CHECKING:
    _ListNamespacesPaginatorBase = Paginator[ListNamespacesResponseTypeDef]
else:
    _ListNamespacesPaginatorBase = Paginator  # type: ignore[assignment]


class ListNamespacesPaginator(_ListNamespacesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListNamespaces.html#S3Tables.Paginator.ListNamespaces)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listnamespacespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNamespacesRequestPaginateTypeDef]
    ) -> PageIterator[ListNamespacesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListNamespaces.html#S3Tables.Paginator.ListNamespaces.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listnamespacespaginator)
        """


if TYPE_CHECKING:
    _ListTableBucketsPaginatorBase = Paginator[ListTableBucketsResponseTypeDef]
else:
    _ListTableBucketsPaginatorBase = Paginator  # type: ignore[assignment]


class ListTableBucketsPaginator(_ListTableBucketsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTableBuckets.html#S3Tables.Paginator.ListTableBuckets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablebucketspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTableBucketsRequestPaginateTypeDef]
    ) -> PageIterator[ListTableBucketsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTableBuckets.html#S3Tables.Paginator.ListTableBuckets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablebucketspaginator)
        """


if TYPE_CHECKING:
    _ListTablesPaginatorBase = Paginator[ListTablesResponseTypeDef]
else:
    _ListTablesPaginatorBase = Paginator  # type: ignore[assignment]


class ListTablesPaginator(_ListTablesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTables.html#S3Tables.Paginator.ListTables)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTablesRequestPaginateTypeDef]
    ) -> PageIterator[ListTablesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables/paginator/ListTables.html#S3Tables.Paginator.ListTables.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_s3tables/paginators/#listtablespaginator)
        """
